# IP Leak

![tests](https://github.com/ProfileID/ipleak/workflows/tests/badge.svg)
[![PyPI package](https://img.shields.io/pypi/v/ipleak)](https://pypi.python.org/pypi/ipleak/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ipleak.svg)](https://pypi.python.org/pypi/ipleak/)
[![PyPI license](https://img.shields.io/pypi/l/ipleak.svg)](https://pypi.python.org/pypi/ipleak/)

Python Tool to check if your VPN Provider is good. Uses ipleak.net
